==> telegram_client-0.5.31.tar.gz: lib/telegram_client/function/get_chat_administrators.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

import 'dart:async';
import 'package:galaxeus_lib/extension/extension.dart';
import 'package:telegram_client/telegram_client/function/get_chat_member.dart';
import 'package:telegram_client/telegram_client/scheme/json_dart.dart';
import 'package:telegram_client/telegram_client/telegram_client.dart';
import 'package:telegram_client/util/util.dart';

/// method GetChatAdministrators
extension GetChatAdministratorsDataOn on TelegramClient {
  /// method GetChatAdministrators
  FutureOr<JsonScheme> getChatAdministrators({
    required Map parameters,
    required FutureOr<JsonScheme> Function({
      required Map parameters,
    }) callApiInvoke,
  }) async {
    dynamic target_chat_id = TgUtils.parse_all_chat_id(parameters: parameters);
    if (target_chat_id is String &&
        RegExp(r"^((@)[a-z0-9_]+)$", caseSensitive: false)
            .hashData(target_chat_id)) {
      var search_public_chat = await callApiInvoke(
        parameters: {
          "@type": "searchPublicChat",
          "username": (target_chat_id)
              .replaceAll(RegExp(r"@", caseSensitive: false), ""),
        },
      );
      if (search_public_chat["@type"] == "chat") {
        parameters["chat_id"] = search_public_chat["id"];
      }
    }
    JsonScheme chat_administrators = await callApiInvoke(
      parameters: {
        "@type": "getChatAdministrators",
        "chat_id": parameters["chat_id"],
      },
    );
    List results = [];
    if (chat_administrators["administrators"] is List) {
      List administrators = (chat_administrators["administrators"] as List);

      for (var i = 0; i < administrators.length; i++) {
        dynamic administrator = administrators[i];
        if (administrator is Map) {
          JsonScheme chat_member = await getChatMember(
            parameters: {
              "chat_id": parameters["chat_id"],
              "user_id": administrator["user_id"],
            },
            callApiInvoke: callApiInvoke,
          );
          results.add(chat_member.rawData);
        }
      }
    }
    return JsonScheme({
      "result": results,
    });
  }
}

==> telegram_client-0.5.56.tar.gz: lib/telegram_client/function/get_chat_administrators.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

import 'dart:async';
import 'package:galaxeus_lib/extension/extension.dart';
import 'package:telegram_client/telegram_client/function/get_chat_member.dart';

import 'package:telegram_client/telegram_client/telegram_client.dart';
import 'package:telegram_client/util/util.dart';

/// method GetChatAdministrators
extension GetChatAdministratorsDataOn on TelegramClient {
  /// method GetChatAdministrators
  FutureOr<Map> getChatAdministrators({
    required Map parameters,
    required FutureOr<Map> Function({
      required Map parameters,
    }) callApiInvoke,
  }) async {
    dynamic target_chat_id = TgUtils.parse_all_chat_id(parameters: parameters);
    if (target_chat_id is String &&
        RegExp(r"^((@)[a-z0-9_]+)$", caseSensitive: false)
            .hashData(target_chat_id)) {
      var search_public_chat = await callApiInvoke(
        parameters: {
          "@type": "searchPublicChat",
          "username": (target_chat_id)
              .replaceAll(RegExp(r"@", caseSensitive: false), ""),
        },
      );
      if (search_public_chat["@type"] == "chat") {
        parameters["chat_id"] = search_public_chat["id"];
      }
    }
    Map chat_administrators = await callApiInvoke(
      parameters: {
        "@type": "getChatAdministrators",
        "chat_id": parameters["chat_id"],
      },
    );
    List results = [];
    if (chat_administrators["administrators"] is List) {
      List administrators = (chat_administrators["administrators"] as List);

      for (var i = 0; i < administrators.length; i++) {
        dynamic administrator = administrators[i];
        if (administrator is Map) {
          Map chat_member = await getChatMember(
            parameters: {
              "chat_id": parameters["chat_id"],
              "user_id": administrator["user_id"],
            },
            callApiInvoke: callApiInvoke,
          );
          results.add(chat_member);
        }
      }
    }
    return ({
      "result": results,
    });
  }
}
